@@ -337,7 +337,7 @@ void MaildirTest::testMaildirFlagsReading()
 {
     QFile file;
     const QStringList markers = QStringList() << QStringLiteral("P") << QStringLiteral("R") << QStringLiteral("S") << QStringLiteral("F") << QStringLiteral("FPRS");
-    QDir::setCurrent(m_temp->path() + QLatin1Char('/') + QStringLiteral("cur"));
+    QDir::setCurrent(m_temp->path() + QStringLiteral("/cur"));
     for (int i = 0; i < 6; i++) {
         QString fileName = QLatin1String("testmail-") + QString::number(i);
         if (i < 5) {
